getErrorPlaceholder static method
Returns the currently set error placeholder or a default one.
Implementation
static ErrorPlaceholder getErrorPlaceholder() {
return _errorPlaceholderBuilder?.call() ?? ErrorPlaceholder();
}
Returns the currently set error placeholder or a default one.
static ErrorPlaceholder getErrorPlaceholder() {
return _errorPlaceholderBuilder?.call() ?? ErrorPlaceholder();
}