getLoadingPlaceholder static method
Returns the currently set loading placeholder or a default one.
Implementation
static LoadingPlaceholder getLoadingPlaceholder() {
return _loadingPlaceholderBuilder?.call() ?? LoadingPlaceholder();
}
Returns the currently set loading placeholder or a default one.
static LoadingPlaceholder getLoadingPlaceholder() {
return _loadingPlaceholderBuilder?.call() ?? LoadingPlaceholder();
}